"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const helpers_1 = require("./helpers");
class Tokenizer {
    tokenize(name, identifier) {
        return identifier ? this.generateCustomIdentifier(name, identifier) : this.createGenericIdentifier(name);
    }
    generateCustomIdentifier(name, identifier) {
        const reversedIdentifier = helpers_1.reverseString(identifier);
        const interpolationsAdded = reversedIdentifier
            .replace(/{(?!\\)/g, `{$`)
            .replace(/}([\w|.]+){(?!\\)\$/g, `}"?"||$1{\$`);
        const cacheKey = helpers_1.reverseString(interpolationsAdded);
        const cacheName = name.replace(/\W/g, "");
        const fnContent = `${cacheName}_tokenizer(url,cookie={},headers={},query={},method){return \`${cacheName}_${cacheKey}\`}`;
        const fn = new Function(`return function ${fnContent}`);
        return fn();
    }
    createGenericIdentifier(name) {
        return (url, cookie, headers, query, method) => {
            return `${name}_${url}_${JSON.stringify({ cookie, headers, query })}_${method}`;
        };
    }
}
exports.Tokenizer = Tokenizer;
//# sourceMappingURL=tokenizer.js.map